InfiniteScrollList class

Inheritance

Constructors

InfiniteScrollList({Key? key, required List<Widget> children, dynamic onLoadingStart(int page)?, bool everythingLoaded = false, EdgeInsetsGeometry? padding, bool shrinkWrap = false, ScrollPhysics? physics, bool reverse = false, bool? primary, double? itemExtent, Widget? prototypeItem, double? cacheExtent, int? semanticChildCount, String? restorationId, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollViewKeyboardDismissBehavior keyboardDismissBehavior = ScrollViewKeyboardDismissBehavior.manual, Clip clipBehavior = Clip.hardEdge, Widget? loadingWidget})
const

Properties

addAutomaticKeepAlives → bool
final
addRepaintBoundaries → bool
final
addSemanticIndexes → bool
final
cacheExtent → double?
final
children → List<Widget>
final
clipBehavior → Clip
final
dragStartBehavior → DragStartBehavior
final
everythingLoaded → bool
final
hashCode → int
The hash code for this object.
no setterinherited
itemExtent → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardDismissBehavior → ScrollViewKeyboardDismissBehavior
final
loadingWidget → Widget?
final
onLoadingStart → dynamic Function(int page)?
final
padding → EdgeInsetsGeometry?
final
physics → ScrollPhysics?
final
primary → bool?
final
prototypeItem → Widget?
final
restorationId → String?
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticChildCount → int?
final
shrinkWrap → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<InfiniteScrollList>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited